@@ -38,11 +38,11 @@ asmlinkage void chacha20_avx512vl(u8 *out, const u8 *in, size_t len, const u32 k
 asmlinkage void poly1305_blocks_avx512(void *ctx, const u8 *inp, size_t len, u32 padbit);
 #endif
 
-static bool chacha20poly1305_use_ssse3 __read_mostly;
-static bool chacha20poly1305_use_avx __read_mostly;
-static bool chacha20poly1305_use_avx2 __read_mostly;
-static bool chacha20poly1305_use_avx512 __read_mostly;
-static bool chacha20poly1305_use_avx512vl __read_mostly;
+static bool chacha20poly1305_use_ssse3 __ro_after_init;
+static bool chacha20poly1305_use_avx __ro_after_init;
+static bool chacha20poly1305_use_avx2 __ro_after_init;
+static bool chacha20poly1305_use_avx512 __ro_after_init;
+static bool chacha20poly1305_use_avx512vl __ro_after_init;
 
 void __init chacha20poly1305_fpu_init(void)
 {
@@ -74,7 +74,7 @@ asmlinkage void poly1305_blocks_neon(void *ctx, const u8 *inp, size_t len, u32 p
 asmlinkage void poly1305_emit_neon(void *ctx, u8 mac[16], const u32 nonce[4]);
 asmlinkage void chacha20_neon(u8 *out, const u8 *in, size_t len, const u32 key[8], const u32 counter[4]);
 #endif
-static bool chacha20poly1305_use_neon __read_mostly;
+static bool chacha20poly1305_use_neon __ro_after_init;
 void __init chacha20poly1305_fpu_init(void)
 {
 #if defined(CONFIG_ARM64)
